@@ -6,9 +6,19 @@
 #include <GL/gl.h>
 #endif
 #ifdef WIN32
-#include <glew.h>
+#include "glew.h"
 #endif
+
+#ifdef __APPLE__
+#include <GL/gl.h>
+#endif
+
+#ifdef USE_DEVIL
+#include <IL/ilut.h>
+#else
 #include "SOIL.h"
+#endif
+
 #include <iostream>
 #include <string>
 #include <map>
@@ -21,6 +31,8 @@ public:
   ~TextureManager();
   TextureManager(std::string _presetURL);
   void unloadTextures(const PresetOutputs::cshape_container &shapes);
+  void Clear();
+  void Preload();
   GLuint getTexture(std::string imageUrl);
   unsigned int getTextureMemorySize();
 };
